# VideoCloud
[![GitHub](https://img.shields.io/github/license/paramt/videocloud.svg)](LICENSE)
[![PyPI](https://img.shields.io/pypi/v/videocloud.svg)](https://pypi.org/project/VideoCloud/)

Generate word clouds from YouTube video captions

## Installation

```
pip install videocloud
```

*Note: A C compiler is required for the installation process.*

## Usage

```
videocloud <link to youtube video> [filepath]
```
If no filepath is given, the wordcloud will be generated in `./videocloud.png`

